import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/Rajashekar551998/a49f9f6fb314798b52ec0fcde3f3e8fc/raw/fde6bce8e0f70a67f5b48d5821e20d0b31b0e785/Assignment-7';  

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5);

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  // Plotting the data on the Scatter Plot
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



